@@ -64,9 +64,9 @@
       (red-cooler      "#cf2f4f")
       (red-faint       "#b05350")
       (green           "#007a0a")
-      (green-warmer    "#5a7400")
+      (green-warmer    "#5f7200")
       (green-cooler    "#0f7f5f")
-      (green-faint     "#617540")
+      (green-faint     "#527545")
       (yellow          "#a45a22")
       (yellow-warmer   "#b75515")
       (yellow-cooler   "#aa4f30")
@@ -208,11 +208,13 @@
 
       (date-common cyan-cooler)
       (date-deadline red)
+      (date-deadline-subtle red-faint)
       (date-event fg-alt)
       (date-holiday red-warmer)
       (date-now fg-main)
       (date-range fg-alt)
       (date-scheduled yellow)
+      (date-scheduled-subtle yellow-faint)
       (date-weekday cyan)
       (date-weekend red-faint)
 
